@@ -110,11 +110,11 @@ def console_main():
                     results_steps,
                     results_setup,
                     results_teardown,
-                    data_tests[history_id]['statusDetails']['trace'] if 'statusDetails' in data_tests[history_id] and data_tests[history_id]['statusDetails'] else None,
+                    data_tests[history_id]['statusDetails']['trace'] if 'statusDetails' in data_tests[history_id] and 'trace' in data_tests[history_id]['statusDetails'] else None,
                     links,
                     data_tests[history_id]['stop'] - data_tests[history_id]['start'],
                     None,
-                    data_tests[history_id]['statusDetails']['message'] if 'statusDetails' in data_tests[history_id] and data_tests[history_id]['statusDetails'] else None,
+                    data_tests[history_id]['statusDetails']['message'] if 'statusDetails' in data_tests[history_id] and 'message' in data_tests[history_id]['statusDetails'] else None,
                     form_parameters(data_tests[history_id]['parameters']) if 'parameters' in data_tests[history_id] else None,
                     attachments
                 )
