@@ -72,7 +72,7 @@ class AttributeReader:
             if not re.fullmatch(r'^(?:(?:(?:https?|ftp):)?//)?(?:(?:[1-9]\d?|1\d\d|2[01]\d|22[0-3])(?:\.(?:1?\d{1,2}|2[0-4]\d|25[0-5])){2}(?:\.(?:[1-9]\d?|1\d\d|2[0-4]\d|25[0-4]))|(?:(?:[a-zA-Z0-9\u00a1-\uffff][a-zA-Z0-9\u00a1-\uffff_-]{0,62})?[a-zA-Z0-9\u00a1-\uffff]\.)+(?:[a-zA-Z\u00a1-\uffff]{2,}\.?))(?::\d{2,5})?(?:[/?#]\S*)?$', args.set_url):
                 print('The wrong URL!')
                 raise SystemExit
-            self.config.set('testit', 'url', args.set_url)
+            self.config.set('testit', 'url', args.set_url if args.set_url[-1] != '/' else args.set_url[:-1])
         if args.set_privatetoken:
             self.config.set('testit', 'privatetoken', args.set_privatetoken)
         if args.set_project:
@@ -101,17 +101,20 @@ class AttributeReader:
                             if file['historyId'] not in data_tests or file['start'] > data_tests[file['historyId']]['start']:
                                 data_tests[file['historyId']] = file
                         elif file_name[-9:] == 'container':
-                            data_before_after[round(os.stat(args.alluredir + full_name).st_ctime_ns)] = json.load(open(args.alluredir + full_name))
+                            container = json.load(open(args.alluredir + full_name, encoding='UTF-8'))
+                            if 'children' in container:
+                                data_before_after[round(os.stat(args.alluredir + full_name).st_ctime_ns)] = container
             elif os.path.isfile(args.alluredir):
                 self.path_to_results = os.path.dirname(os.path.abspath(args.alluredir))
-                print('dirname: ', os.path.dirname(os.path.abspath(args.alluredir)))
                 file_name, file_extension = os.path.splitext(args.alluredir)
                 if file_extension == '.json':
                     if file_name[-6:] == 'result':
-                        file = json.load(open(args.alluredir))
+                        file = json.load(open(args.alluredir, encoding='UTF-8'))
                         data_tests[file['historyId']] = file
                     elif file_name[-9:] == 'container':
-                        data_before_after[round(os.stat(args.alluredir).st_ctime_ns)] = json.load(open(args.alluredir))
+                        container = json.load(open(args.alluredir, encoding='UTF-8'))
+                        if 'children' in container:
+                            data_before_after[round(os.stat(args.alluredir).st_ctime_ns)] = container
 
         if args.set_url or args.set_privatetoken or args.set_project or args.set_configuration:
             with open(self.path_to_config, "w") as config_file:
